@@ -1,12 +1,11 @@
 import json
-from pathlib import Path
+import os
 
 import pytest
-from appdirs import user_config_dir
 
 from latexplotlib import _latexplotlib as lpl
 
-GOLDEN_RATIO = (5 ** 0.5 + 1) / 2
+GOLDEN_RATIO = (5**0.5 + 1) / 2
 HEIGHT = 630
 WIDTH = 412
 
@@ -16,13 +15,12 @@ NAME = "latexplotlib"
 
 
 def test_constants():
-    assert lpl.GOLDEN_RATIO == GOLDEN_RATIO
-    assert lpl.HEIGHT == HEIGHT
-    assert lpl.WIDTH == WIDTH
-    assert lpl.CONFIGFILE == CONFIGFILE
-    assert lpl.NAME == NAME
-    assert lpl.CONFIGDIR == Path(user_config_dir(NAME))
-    assert lpl.CONFIGPATH == lpl.CONFIGDIR.joinpath(CONFIGFILE)
+    assert lpl.GOLDEN_RATIO
+    assert lpl.CONFIGFILE
+    assert lpl.NAME
+    assert lpl.CONFIGDIR
+    assert lpl.CONFIGPATH
+    assert lpl.DEFAULT_CONFIG
 
 
 @pytest.mark.parametrize("value", [123.234, 23.4576585, 234])
@@ -30,6 +28,114 @@ def test__round(value):
     assert int(10 * value) / 10 == lpl._round(value)
 
 
+class Test_Config:
+    @pytest.fixture
+    def default(self):
+        return {"apple": 10, "egg": 1}
+
+    @pytest.fixture
+    def config(self, default, tmp_path, monkeypatch):
+        monkeypatch.setattr(lpl, "DEFAULT_CONFIG", default)
+        return lpl.Config(tmp_path.joinpath("tmp.ini"))
+
+    def test___init__(self, tmp_path):
+        path = tmp_path.joinpath("tmp.ini")
+        config = lpl.Config(path)
+
+        assert config.path == path
+
+    def test_write(self, config, default):
+        config._write(default)
+
+        assert os.path.exists(config.path)
+
+        with open(config.path, "r", encoding="utf-8") as fh:
+            cfg = json.load(fh)
+        assert cfg == default
+
+    def test_reset(self, config, default, mocker):
+        default = {"apple": 10, "egg": 1}
+        config._write(default)
+        assert os.path.exists(config.path)
+
+        mocker.patch.object(config, "_write")
+
+        config.reset()
+
+        assert not os.path.exists(config.path)
+        config._write.assert_called_once_with(default)
+
+    def test__config_with_reset(self, config, default, mocker):
+        mocker.spy(config, "reset")
+        assert not os.path.exists(config.path)
+
+        cfg = config._config()
+
+        config.reset.assert_called_once_with()
+        assert cfg == default
+
+    def test__config_wo_reset(self, config, default, mocker):
+        config._write(default)
+        mocker.spy(config, "reset")
+        assert os.path.exists(config.path)
+
+        cfg = config._config()
+
+        config.reset.assert_not_called()
+        assert cfg == default
+
+    def test___getitem__(self, config, default):
+        config.reset()
+
+        for key, item in default.items():
+            assert config[key] == item
+
+    def test___setitem__(self, config, default):
+        config.reset()
+
+        config["skyscraper"] = "apple"
+
+        assert config["skyscraper"] == "apple"
+
+
+class Test_Size:
+    @pytest.fixture
+    def config(self, monkeypatch):
+        monkeypatch.setattr(lpl, "config", {"width": 10, "height": 20})
+
+    @pytest.fixture
+    def size(self):
+        return lpl.Size()
+
+    def test___init__(self, config):
+        size = lpl.Size()
+
+        assert size._width == 10
+        assert size._height == 20
+
+    def test_get(self, config, size):
+        assert size.get() == (10, 20)
+
+    def test_set(self, config, size):
+        size.set(43, 44)
+        assert size.get() == (43, 44)
+
+    def test_context(self, config, size):
+        assert size.get() == (10, 20)
+
+        with size.context(44, 43):
+            assert size.get() == (44, 43)
+
+        assert size.get() == (10, 20)
+
+    def test_str(self, size):
+        str(size)
+
+    def test_repr(self, size):
+        repr(size)
+
+
+@pytest.mark.skip(reason="Deprecated")
 class TestSetPageSize:
     def test_dir_exists(self, monkeypatch, tmp_path):
         configpath = tmp_path.joinpath("tmp.ini")
@@ -59,6 +165,7 @@ class TestSetPageSize:
         assert config["width"] == WIDTH
 
 
+@pytest.mark.skip(reason="Deprecated")
 class TestGetPageSize:
     def test_file_exists(self, monkeypatch, tmp_path):
         configpath = tmp_path.joinpath("tmp.ini")
@@ -85,6 +192,7 @@ class TestGetPageSize:
         assert width == WIDTH
 
 
+@pytest.mark.skip(reason="Deprecated")
 class TestResetPageSize:
     def test_exists(self, monkeypatch, tmp_path):
         configpath = tmp_path.joinpath("tmp.ini")
